@@ -14,6 +14,7 @@ The JSON manifest files used have the following simple form:
     ...
 ]
 """
+import gzip
 import json
 import logging
 import os.path
@@ -133,9 +134,16 @@ def submit(files, manifest_file, userid, token):
     for infile, job in zip(files, manifest):
         jobid = job['jobid']
         key = os.path.basename(job['filepath'])
+        # Compress to handle larger files (API Gateway limit = 10MB.
+        # Requires explicit Content-Type: application/gzip header here in the
+        # request and in API Gateway / Settings / Binary Media Types 
+        payload = gzip.compress(infile.read())
+        infile.close()
         response = requests.put(
-            f"{APISUBMIT}/{userid}/{jobid}/{key}",
-            data=infile.read(),
-            headers={'Authorization': token})
+            f"{APISUBMIT}/{userid}/{jobid}/{key}.gz",
+            data=payload,
+            headers={
+                'Authorization': token,
+                'Content-Type': 'application/gzip'})
         response.raise_for_status()
     LOGGER.info(manifest_str)
